==> jira-editor-plugin-1.2.30.jar: js/ui/button-bar-decorator-tests.js <==
AJS.test.require(["com.atlassian.jira.plugins.jira-editor-plugin:undo-redo-ui"], function () {

    var $ = require("jquery");
    var ButtonBarDecorator = require("jira/editor/ui/button-bar-decorator");

    module("ButtonBarDecorator", {
        setup: function () {
            this.sandbox = sinon.sandbox.create({});

            this.buttonBarDecorator = new ButtonBarDecorator();

            this.$defaultWikiHtml = $('<div id="test-default"><div class="field-group aui-field-wikiedit comment-input">' +
                '<div class="jira-wikifield" field-id="comment" renderer-type="atlassian-wiki-renderer" issue-key="TEST-10" resolved="">' +
                '<div class="wiki-edit">' +
                '<div id="comment-wiki-edit" class="wiki-edit-content">' +
                '<div class="aui-tabs horizontal-tabs editor-toggle-tabs" role="application">' +
                '<ul class="tabs-menu" role="tablist">' +
                '<li class="menu-item" data-mode="source" role="presentation">' +
                '<a href="#" id="aui-uid-1" role="tab" aria-selected="false">Text' +
                '</a>' +
                '</li>' +
                '<li class="menu-item active-tab" data-mode="wysiwyg" role="presentation">' +
                '<a href="#" id="aui-uid-2" role="tab" aria-selected="true">Visual' +
                '</a>' +
                '</li>' +
                '</ul>' +
                '</div>' +
                '<span class="aui-label editor-toggle-tooltip">' +
                '</span>' +
                '</div>' +
                '</div>' +
                '<div class="field-tools">' +
                '</div>' +
                '</div>' +
                '<div class="save-options wiki-button-bar">' +
                '<div class="wiki-edit-undo-redo-buttons aui-buttons wiki-edit-separate-section">' +
                '<button type="button" class="aui-button aui-button-subtle wiki-operation-undo" disabled="disabled" aria-disabled="true">' +
                '<span class="aui-icon aui-icon-small aui-iconfont-undo" aria-disabled="true" disabled="">Undo' +
                '</span>' +
                '</button>' +
                '<button type="button" class="aui-button aui-button-subtle wiki-operation-redo" disabled="disabled" aria-disabled="true">' +
                '<span class="aui-icon aui-icon-small aui-iconfont-redo" aria-disabled="true" disabled="">Redo' +
                '</span>' +
                '</button>' +
                '</div>' +
                '<div class="security-level" resolved="">' +
                '</div>' +
                '<input accesskey="s" class="aui-button aui-button-light" id="issue-comment-add-submit" name="Add" title="Press Alt+s to submit this form" type="submit" value="Add" disabled="disabled">' +
                '<a accesskey="`" class="aui-button aui-button-link cancel" href="#" id="issue-comment-add-cancel" title="Press Alt+` to cancel">Cancel' +
                '</a>' +
                '</div>' +
                '</div></div>');

            this.$inlineEditWikiHtml =
                $('<div id="test-inline"><div class="inline-edit-fields show-button-bar" tabindex="1">' +
                '<div class="field-group">' +
                '<div class="jira-wikifield" field-id="description" renderer-type="atlassian-wiki-renderer" issue-key="TEST-10" resolved="">' +
                '<div class="wiki-edit">' +
                '<div id="description-wiki-edit" class="wiki-edit-content">' +
                '<textarea class="richeditor-cover" id="description" name="description">' +
                '</textarea>' +
                '<textarea class="textarea long-field wiki-textfield long-field mentionable richeditor-cover" rows="12" wrap="virtual" data-projectkey="TEST" data-issuekey="TEST-10" resolved="" style="height: 60px;">' +
                '</textarea>' +
                '<div class="aui-tabs horizontal-tabs editor-toggle-tabs" role="application">' +
                '<ul class="tabs-menu" role="tablist">' +
                '<li class="menu-item" data-mode="source" role="presentation">' +
                '<a href="#" id="aui-uid-3" role="tab" aria-selected="false">Text' +
                '</a>' +
                '</li>' +
                '<li class="menu-item active-tab" data-mode="wysiwyg" role="presentation">' +
                '<a href="#" id="aui-uid-4" role="tab" aria-selected="true">Visual' +
                '</a>' +
                '</li>' +
                '</ul>' +
                '</div>' +
                '</div>' +
                '</div>' +
                '</div>' +
                '<div class="save-options wiki-button-bar" tabindex="1">' +
                '<div class="existing">existing</div>' +
                '</div>' +
                '</div>' +
                '</div>' +
                '<span class="overlay-icon throbber"></span>' +
                '<div class="save-options show-button-bar" tabindex="1">' +
                '<div class="wiki-edit-undo-redo-buttons aui-buttons"></div>' +
                '<div class="field-tools"></div>' +
                '<button type="submit" class="aui-button aui-button-light submit" accesskey="s" title="Press Alt+s to submit this form">Save</button>' +
                '<button type="cancel" class="aui-button aui-button-link cancel" accesskey="`" title="Press Alt+` to cancel">Cancel</button>' +
                '</div>' +
                '</div>');

            $("#qunit-fixture").append(this.$defaultWikiHtml);
            $("#qunit-fixture").append(this.$inlineEditWikiHtml);

            this.$tabsDefault = $('#test-default .editor-toggle-tabs');
            this.$tabsInline = $('#test-inline .editor-toggle-tabs');

            this.$tabsDefault.width(123).height(321);
            this.$tabsInline.width(234).height(432);
        },

        teardown: function () {
            this.sandbox.restore();
        }
    });

    test("Should correctly decorate default wiki button bar", function (done) {
        var $bar = this.$defaultWikiHtml.find('.wiki-button-bar');
        var barChildrenLength = $bar.children().length;

        this.buttonBarDecorator.decorateButtonBars(this.$tabsDefault);

        equal($bar.children().length, 3);
        equal($bar.find('.tabs-placeholder').length, 1);
        equal($bar.find('.tabs-placeholder').width(), 123);
        equal($bar.find('.tabs-placeholder').height(), 321);
        equal($bar.find('.wiki-button-bar-content').length, 1);
        equal($bar.find('.wiki-button-bar-content').children().length, barChildrenLength);
    });

    test("Should correctly decorate inline edit button bar", function (done) {
        var $bar = this.$inlineEditWikiHtml.find('.save-options.show-button-bar');
        var barChildrenLength = $bar.children().length;

        this.buttonBarDecorator.decorateButtonBars(this.$tabsInline);

        equal($bar.children().length, 3);
        equal($bar.find('.tabs-placeholder').length, 1);
        equal($bar.find('.tabs-placeholder').width(), 234);
        equal($bar.find('.tabs-placeholder').height(), 432);
        equal($bar.find('.wiki-button-bar-content').length, 1);
        equal($bar.find('.wiki-button-bar-content').children().length, barChildrenLength);
    });
});

==> jira-editor-plugin-4.2.10.jar: js/ui/button-bar-decorator-tests.js <==
AJS.test.require(["com.atlassian.jira.plugins.jira-editor-plugin:undo-redo-ui"], function () {

    var $ = require("jquery");
    var ButtonBarDecorator = require("jira/editor/ui/button-bar-decorator");

    module("ButtonBarDecorator", {
        setup: function () {
            this.sandbox = sinon.sandbox.create({});

            this.buttonBarDecorator = new ButtonBarDecorator();

            this.$defaultWikiHtml = $('<div id="test-default"><div class="field-group aui-field-wikiedit comment-input">' +
                '<div class="jira-wikifield" field-id="comment" renderer-type="atlassian-wiki-renderer" issue-key="TEST-10" resolved="">' +
                '<div class="wiki-edit">' +
                '<div id="comment-wiki-edit" class="wiki-edit-content">' +
                '<div class="aui-tabs horizontal-tabs editor-toggle-tabs" role="application">' +
                '<ul class="tabs-menu" role="tablist">' +
                '<li class="menu-item" data-mode="source" role="presentation">' +
                '<a href="#" id="aui-uid-1" role="tab" aria-selected="false">Text' +
                '</a>' +
                '</li>' +
                '<li class="menu-item active-tab" data-mode="wysiwyg" role="presentation">' +
                '<a href="#" id="aui-uid-2" role="tab" aria-selected="true">Visual' +
                '</a>' +
                '</li>' +
                '</ul>' +
                '</div>' +
                '<span class="aui-label editor-toggle-tooltip">' +
                '</span>' +
                '</div>' +
                '</div>' +
                '<div class="field-tools">' +
                '</div>' +
                '</div>' +
                '<div class="save-options wiki-button-bar">' +
                '<div class="wiki-edit-undo-redo-buttons aui-buttons wiki-edit-separate-section">' +
                '<button type="button" class="aui-button aui-button-subtle wiki-operation-undo" disabled="disabled" aria-disabled="true">' +
                '<span class="aui-icon aui-icon-small aui-iconfont-undo" aria-disabled="true" disabled="">Undo' +
                '</span>' +
                '</button>' +
                '<button type="button" class="aui-button aui-button-subtle wiki-operation-redo" disabled="disabled" aria-disabled="true">' +
                '<span class="aui-icon aui-icon-small aui-iconfont-redo" aria-disabled="true" disabled="">Redo' +
                '</span>' +
                '</button>' +
                '</div>' +
                '<div class="security-level" resolved="">' +
                '</div>' +
                '<input accesskey="s" class="aui-button aui-button-primary" id="issue-comment-add-submit" name="Add" title="Press Alt+s to submit this form" type="submit" value="Add" disabled="disabled">' +
                '<a accesskey="`" class="aui-button aui-button-link cancel" href="#" id="issue-comment-add-cancel" title="Press Alt+` to cancel">Cancel' +
                '</a>' +
                '</div>' +
                '</div></div>');

            this.$inlineEditWikiHtml =
                $('<div id="test-inline"><div class="inline-edit-fields show-button-bar" tabindex="1">' +
                '<div class="field-group">' +
                '<div class="jira-wikifield" field-id="description" renderer-type="atlassian-wiki-renderer" issue-key="TEST-10" resolved="">' +
                '<div class="wiki-edit">' +
                '<div id="description-wiki-edit" class="wiki-edit-content">' +
                '<textarea class="richeditor-cover" id="description" name="description">' +
                '</textarea>' +
                '<textarea class="textarea long-field wiki-textfield long-field mentionable richeditor-cover" rows="12" wrap="virtual" data-projectkey="TEST" data-issuekey="TEST-10" resolved="" style="height: 60px;">' +
                '</textarea>' +
                '<div class="aui-tabs horizontal-tabs editor-toggle-tabs" role="application">' +
                '<ul class="tabs-menu" role="tablist">' +
                '<li class="menu-item" data-mode="source" role="presentation">' +
                '<a href="#" id="aui-uid-3" role="tab" aria-selected="false">Text' +
                '</a>' +
                '</li>' +
                '<li class="menu-item active-tab" data-mode="wysiwyg" role="presentation">' +
                '<a href="#" id="aui-uid-4" role="tab" aria-selected="true">Visual' +
                '</a>' +
                '</li>' +
                '</ul>' +
                '</div>' +
                '</div>' +
                '</div>' +
                '</div>' +
                '<div class="save-options wiki-button-bar" tabindex="1">' +
                '<div class="existing">existing</div>' +
                '</div>' +
                '</div>' +
                '</div>' +
                '<span class="overlay-icon throbber"></span>' +
                '<div class="save-options show-button-bar" tabindex="1">' +
                '<div class="wiki-edit-undo-redo-buttons aui-buttons"></div>' +
                '<div class="field-tools"></div>' +
                '<button type="submit" class="aui-button aui-button-primary submit" accesskey="s" title="Press Alt+s to submit this form">Save</button>' +
                '<button type="cancel" class="aui-button aui-button-link cancel" accesskey="`" title="Press Alt+` to cancel">Cancel</button>' +
                '</div>' +
                '</div>');

            $("#qunit-fixture").append(this.$defaultWikiHtml);
            $("#qunit-fixture").append(this.$inlineEditWikiHtml);

            this.$tabsDefault = $('#test-default .editor-toggle-tabs');
            this.$tabsInline = $('#test-inline .editor-toggle-tabs');

            this.$tabsDefault.width(123).height(321);
            this.$tabsInline.width(234).height(432);
        },

        teardown: function () {
            this.sandbox.restore();
        }
    });

    test("Should correctly decorate default wiki button bar", function (done) {
        var $bar = this.$defaultWikiHtml.find('.wiki-button-bar');
        var barChildrenLength = $bar.children().length;

        this.buttonBarDecorator.decorateButtonBars(this.$tabsDefault);

        equal($bar.children().length, 3);
        equal($bar.find('.tabs-placeholder').length, 1);
        equal($bar.find('.tabs-placeholder').width(), 123);
        equal($bar.find('.tabs-placeholder').height(), 321);
        equal($bar.find('.wiki-button-bar-content').length, 1);
        equal($bar.find('.wiki-button-bar-content').children().length, barChildrenLength);
    });

    test("Should correctly decorate inline edit button bar", function (done) {
        var $bar = this.$inlineEditWikiHtml.find('.save-options.show-button-bar');
        var barChildrenLength = $bar.children().length;

        this.buttonBarDecorator.decorateButtonBars(this.$tabsInline);

        equal($bar.children().length, 3);
        equal($bar.find('.tabs-placeholder').length, 1);
        equal($bar.find('.tabs-placeholder').width(), 234);
        equal($bar.find('.tabs-placeholder').height(), 432);
        equal($bar.find('.wiki-button-bar-content').length, 1);
        equal($bar.find('.wiki-button-bar-content').children().length, barChildrenLength);
    });
});
